# Some code to create 'Functional Biodiversity' graphs
# Created by Rainer Froese in January/February 2022

# general settings
rm(list=ls(all=TRUE)) # clear previous variables etc
options(digits=3) # displays all numbers with three significant digits as default
graphics.off() # close graphics windows from previous sessions


# Read file with FishBase data on Phylogeny, Length, Resilience, and Troph
#setwd("D:/RF_Documents/BioDiv2022")
Bdat         <- read.csv("BioDiv_14.csv", header=T, dec=".", stringsAsFactors = FALSE)
cat("Files BioDiv_14.csv read successfully","\n\n")

# Read Order ages
OAgeRaw     <- read.csv("OrderAge.csv", header=T, dec=".", stringsAsFactors = FALSE)
OOrders     <- unique(OAgeRaw$Order)
OAgeU        <- vector()
for(i in 1: length(OOrders)){
  OAgeU[i] <- min(OAgeRaw$CommonAncestor[OAgeRaw$Order==OOrders[i]])
}


# Define key parameters
sp    <- Bdat$SpecCode
res   <- Bdat$Resilience
bw    <- Bdat$Wmax
OAge  <- vector()
for(i in 1:length(sp)){
  OAge[i] <- OAgeU[OOrders==Bdat$Order[i]]
}

# fix some errors
bw[sp==1248]    <- 6000
bw[sp==27028]   <- 6400
bw[sp==59949]   <- 3
bw[sp==59953]   <- 3
res[sp==53414]  <- "High"
res[sp==54548]  <- "High"
res[sp==13639]  <- "Medium"
res[sp==147]    <- "Medium"
res[sp==223]    <- "Medium"
res[sp==7734]   <- "Low"

mean.log.bw <- mean(log10(bw))
sd.log.bw   <- sd(log10(bw))
size  <- vector() 
for(i in 1:length(bw)) {
 if(log10(bw[i]) < (mean.log.bw-sd.log.bw)) {sz = "Small"} else {
   if(log10(bw[i]) < (mean.log.bw+sd.log.bw)) {sz = "Medium"} else {
     if(log10(bw[i]) < (mean.log.bw+3*sd.log.bw)) {sz = "Large"} else {sz = "Very large"}}}
  size <- append(size,sz) 
}

# get observed trophs
obs.troph <- vector()
for(i in 1:length(sp)) {
  if(is.na(Bdat$DietTroph[i])==F && is.na(Bdat$FoodTroph[i])==F) {
    obs.troph[i] <- mean(c(Bdat$DietTroph[i],Bdat$FoodTroph[i]))
  } else {if(is.na(Bdat$DietTroph[i])==F) {
      obs.troph[i] <- Bdat$DietTroph[i]
    } else {obs.troph[i] <- Bdat$FoodTroph[i]} 
  }  
}

# fixing some troph errors in FB
obs.troph[sp==7569]  <- 2.05 
obs.troph[sp==11942] <- 3
obs.troph[sp==6238]  <- 3
obs.troph[sp==6239]  <- 3
obs.troph[sp==52632] <- 3
obs.troph[sp==62262] <- 3
obs.troph[sp==23546] <- 3.8
obs.troph[sp==8718]  <- 4
obs.troph[sp==1248]  <- 4.25


# get predicted trophs for species that have none
pred.troph <- vector()
intercept  <- median(obs.troph[Bdat$MaxLengthTL<3],na.rm=T) # median of observed trophs for fish < 2 cm
cat("Median of observed trophs for fish < 3 cm",intercept,", n =",length(obs.troph[is.na(obs.troph)==F & Bdat$MaxLengthTL<3]),"\n\n")
for(i in 1:length(sp)){
  if(is.na(obs.troph[i])==F) {pred.troph[i] <- NA; next} else { 
    gen  <- Bdat$Genus[i]
    subf <- Bdat$Subfamily[i]
    fam  <- Bdat$Family[i]
    ord  <- Bdat$Order[i]
    if(length(obs.troph[is.na(obs.troph)==F & Bdat$Genus==gen])>=1) {
      tr  <- obs.troph[is.na(obs.troph)==F & Bdat$Genus==gen]
      tl  <- Bdat$MaxLengthTL[is.na(obs.troph)==F & Bdat$Genus==gen]
      reg <- lm(tr ~ log10(tl) + 0 + offset(rep(intercept,length(tr))))
      slp <- reg$coefficients[1]
      pred.troph[i] <- intercept + slp * log10(Bdat$MaxLengthTL[i])
    } else if(length(obs.troph[is.na(obs.troph)==F & Bdat$Subfamily==subf])>=1) {
        tr   <- obs.troph[is.na(obs.troph)==F & Bdat$Subfamily==subf]
        tl   <- Bdat$MaxLengthTL[is.na(obs.troph)==F & Bdat$Subfamily==subf]
        reg  <- lm(tr ~ log10(tl) + 0 + offset(rep(intercept,length(tr))))
        slp  <- reg$coefficients[1]
        pred.troph[i] <- intercept + slp * log10(Bdat$MaxLengthTL[i])
      } else if(length(obs.troph[is.na(obs.troph)==F & Bdat$Family==fam])>=1) {
          tr   <- obs.troph[is.na(obs.troph)==F & Bdat$Family==fam]
          tl   <- Bdat$MaxLengthTL[is.na(obs.troph)==F & Bdat$Family==fam]
          reg  <- lm(tr ~ log10(tl) + 0 + offset(rep(intercept,length(tr))))
          slp  <- reg$coefficients[1]
          pred.troph[i] <- intercept + slp * log10(Bdat$MaxLengthTL[i]) 
        } else if(length(obs.troph[is.na(obs.troph)==F & Bdat$Order==ord])>=1) {
            tr   <- obs.troph[is.na(obs.troph)==F & Bdat$Order==ord]
            tl   <- Bdat$MaxLengthTL[is.na(obs.troph)==F & Bdat$Order==ord]
            reg  <- lm(tr ~ log10(tl) + 0 + offset(rep(intercept,length(tr))))
            slp  <- reg$coefficients[1]
            pred.troph[i] <- intercept + slp * log10(Bdat$MaxLengthTL[i]) 
         } else pred.troph[i] <-100 # to alert of Order without troph
  }
  if(pred.troph[i]<2) pred.troph[i] <- 2 
}

# scatterplot of observed troph over body length for Oreochromis and Scombridae
windows(12,8)
plot(x=Bdat$MaxLengthTL[Bdat$Genus=="Oreochromis"],y=obs.troph[Bdat$Genus=="Oreochromis"],
     xlim=c(1,300),ylim=c(2,4.5),ylab="Trophic level",xlab="Body length (cm)", 
     log="x",pch=20,col="green",bty="l")
lines(x=c(1,73.2),y=c(intercept,2.07),col="green")
points(x=Bdat$MaxLengthTL[Bdat$Family=="Scombridae"],y=obs.troph[Bdat$Family=="Scombridae"],pch=20,col="red")
lines(x=c(1,250),y=c(intercept,4.34),col="red")
points(x=Bdat$MaxLengthTL[Bdat$MaxLengthTL<3],y=obs.troph[Bdat$MaxLengthTL<3],pch=20)
text(x=46,y=4.27,"Scombridae")
text(x=76,y=2.35,"Oreochromis")
text(x=2.5,y=3.6,"Misc. small species")

# scatterplot of observed troph over predicted troph over length
windows(12,8)
plot(x=Bdat$MaxLengthTL,y=pred.troph,log="x",pch=20,col="grey",bty="l")
points(x=Bdat$MaxLengthTL,y=obs.troph,pch=20,cex=0.5)

# scatter plot of trophic level over body weight
windows(12,8)
plot(x=bw,y=pred.troph,log="x",bty="l",pch=20,col="grey80",xlab="Body weight", #,cex=0.5
     ylab="Trophic level",xlim = c(0.001,100000000),xaxt="n")
axis(1,at=c(10^-3,10^-1,10^1,10^3,10^5,10^7),labels=c("0.001 g","0.1 g","10 g","1 kg","100 kg","10 tonnes"))
points(x=bw,y=obs.troph,pch=20,cex=0.5)

# combine observed and predicted trophs
troph <- vector()
for(i in 1:length(sp)){
  troph[i] <- ifelse(is.na(obs.troph[i])==F,obs.troph[i],pred.troph[i])
}

# plot histogram of body weights
windows(12,8)
h <- hist(log10(bw),breaks = 50,xaxt="n",main="",xlab="Maximum body weight (g)")
axis(1, at = pretty(h$breaks), labels = 10^pretty(h$breaks))
abline(v=mean.log.bw-3*sd.log.bw,lty="dashed")
abline(v=mean.log.bw-sd.log.bw,lty="dashed")
abline(v=mean.log.bw+sd.log.bw,lty="dashed")
abline(v=mean.log.bw+3*sd.log.bw,lty="dashed")
text(x=-1,y=2000,paste("Small\n0.004 - 1.99 g\n",length(bw[bw<2])))
text(x=2,y=2000,paste("Medium\n2 - 692 g\n",length(bw[bw>=2&bw<693])))
text(x=4,y=2000,paste("Large\n693 g - 241 kg\n",length(bw[bw>=693&bw<241200])))
text(x=6.6,y=2000,paste("Very large\n241 kg - 34 tonnes\n",length(bw[bw>=2&bw>=241200])))

# boxplot of size by productivity group
windows(12,8)
par(bty="l")
# determine order of boxplots
datbox <- data.frame(res,bw)
datbox$res <- factor(datbox$res,levels=c("Very low","Low","Medium","High"))
bp.res <- boxplot((datbox$bw) ~ datbox$res, log="y", notch=F,ylim=c(0.001,100000),
        outline=F,xlab = "Productivity",ylab="Body weight (g)")
text(x=c(1:4),
     y=2.5*bp.res$stats[nrow(bp.res$stats),],
     paste("n = ",table(datbox$res),sep=""))
text(x=c(1:4),
     y=2.1*bp.res$stats[3,],
     format(bp.res$stats[3,],digits=1))

# boxplot of troph by productivity group
windows(12,8)
par(bty="l")
# determine order of boxplots
datbox <- data.frame(res,troph)
datbox$res <- factor(datbox$res,levels=c("Very low","Low","Medium","High"))
bp <- boxplot((datbox$troph) ~ datbox$res,notch=F,outline=F,xlab = "Productivity",
        ylab="Trophic level",ylim=c(2,5))

cat("       Very low       Low           Medium          High")
print(summary(bp$stats))
cat("\n\n")


# Create trophic groups and assign them to trophic levels
tr.grp     <- c("Herbivores","Omnivores","Low-level predators","Mid-level predators","Top predators")
troph.grp  <- vector() 
for(i in 1:length(Bdat$SpecCode)) {
  if(troph[i] <= 2.2) {troph.grp[i] = "Herbivores"} else {
    if(troph[i] <= 2.8) {troph.grp[i] = "Omnivores"} else {
      if(troph[i] <= 3.8) {troph.grp[i] = "Low-level predators"} else {
        if(troph[i] <= 4.2) {troph.grp[i] = "Mid-level predators"} else {
          troph.grp[i] = "Top predators"}}}}
}

print(summary(as.factor(troph.grp)))
cat("\n\n")

# histogram of trophs
windows(12,8)
hist(troph, breaks=25,main="",xlab="Trophic level",col=
       c(rep("forestgreen",2),rep("chartreuse1",6),
         rep("yellow",10),rep("orange",4),rep("red",6)),border="grey")
legend("topright",legend=c("Top predators","Mid-level predators","Low-level predators","Omnivores","Herbivores"),
       pch=15,pt.cex=1.5,col=c("red","orange","yellow","chartreuse1","forestgreen"),box.lty=0)
# add observed trophs to histogram
hist(obs.troph, breaks=25,col=
       c(rep("forestgreen",2),rep("chartreuse1",6),
         rep("yellow",10),rep("orange",4),rep("red",6)),border="grey",add=T)
text(x=3.4,y=1500,"predicted",font=2)
text(x=3.42,y=300,"observed",font=2)

# boxplot of size by trophic group
windows(12,8)
par(bty="l")
# determine order of boxplots
datbox <- data.frame(troph.grp,bw)
datbox$troph.grp <- factor(datbox$troph.grp,levels=c("Herbivores","Omnivores","Low-level predators","Mid-level predators","Top predators"))
bpt <- boxplot((datbox$bw) ~ datbox$troph.grp, log="y", notch=F,ylim=c(0.001,100000),
                  outline=F,xlab = "Trophic group",ylab="Body weight (g)",
                  names=c("Herbivores","Omnivores","Low-level","Mid-level","Top predators"))
text(x=c(1:5),
     y=2.1*bpt$stats[nrow(bp$stats),],
     paste("n = ",table(datbox$troph.grp),sep=""))
text(x=c(1:5),
     y=2.1*bpt$stats[3,],
     format(bpt$stats[3,],digits=1))

#------------------------------------------------------
# boxplot of egg diameter by climate zone / temperature
# read data
Eggdat     <- read.csv("EggDiam.csv", header=T, dec=".", stringsAsFactors = FALSE)
diam       <- Eggdat$EggDiameter#[Eggdat$Saltwater==1]
clim       <- Eggdat$EnvTemp#[Eggdat$Saltwater==1]
for(i in 1:length(clim)){
  if(clim[i]=="polar" | clim[i]=="deep-water") {clim[i] <- "polar/deep"}
}
# determine order of boxplots
climbox      <- data.frame(clim,diam)
climbox$clim <- factor(climbox$clim,levels=c("tropical","subtropical","temperate","polar/deep"))
windows(12,8)
par(bty="l")
cpt <- boxplot((climbox$diam) ~ climbox$clim, notch=F,ylim=c(0,5.5),  
               outline=F,xlab = "Climate zone",ylab="Egg diameter (mm)",
               names=c("tropical","subtropical","temperate","polar/deep"))

# show number of observations
text(x=c(1:4),
     #y=2.1*bpt$stats[nrow(bp$stats),],
     y=cpt$stats[nrow(cpt$stats),]+0.23,
     paste("n = ",table(climbox$clim),sep=""))
text(x=c(1:5),
     y=cpt$stats[3,]+0.21,
     format(cpt$stats[3,],digits=1))


#------------------------------------------------------------------------------------------------------------
# All species biodiv plot
#------------------------------------------------------------------------------------------------------------
# Create resilience and size groups and matrix to store counts
res.grp       <- c("High","Medium","Low","Very low")
sz.grp        <- c("Small","Medium","Large","Very large")
res.sz.counts <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.counts) <- res.grp
colnames(res.sz.counts) <- sz.grp
res.sz.age    <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.age) <- res.grp
colnames(res.sz.age) <- sz.grp

# get number of species per size group and resilience group
res.count  <- vector(); for(i in 1:4) {res.count[i] <- length(res[res==res.grp[i]]) }
sz.count   <- vector(); for(i in 1:4) {sz.count[i] <- length(size[size==sz.grp[i]]) }

# assign counts of species to matrix, add totals to matrix and print matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.counts[j,i] <- length(Bdat$SpecCode[size==i & res==j]) 
  }
}
res.sz.counts <- cbind(res.sz.counts,res.count)
sz.count      <- append(sz.count,length(res))
res.sz.counts <- rbind(res.sz.counts,sz.count)
print(res.sz.counts)

# get median age of Orders of species in a cell, assign to res.sz.age matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.age[j,i] <- median(OAge[size==i & res==j]) 
  }
}

# for every combination of size and productivity, get number of species per trophic group,  
res.sz.herb <- matrix(,nrow=4,ncol = 4);rownames(res.sz.herb) <- res.grp;colnames(res.sz.herb) <- sz.grp
res.sz.omn   <- matrix(,nrow=4,ncol = 4);rownames(res.sz.omn)  <- res.grp;colnames(res.sz.omn) <- sz.grp
res.sz.low  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.low) <- res.grp;colnames(res.sz.low) <- sz.grp
res.sz.mid  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.mid) <- res.grp;colnames(res.sz.mid) <- sz.grp
res.sz.top  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.top) <- res.grp;colnames(res.sz.top) <- sz.grp
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.herb[j,i] <- length(Bdat$SpecCode[size==i & res==j & troph.grp=="Herbivores"])
    res.sz.omn[j,i] <- length(Bdat$SpecCode[size==i & res==j & troph.grp=="Omnivores"])
    res.sz.low[j,i] <- length(Bdat$SpecCode[size==i & res==j & troph.grp=="Low-level predators"])
    res.sz.mid[j,i] <- length(Bdat$SpecCode[size==i & res==j & troph.grp=="Mid-level predators"])
    res.sz.top[j,i] <- length(Bdat$SpecCode[size==i & res==j & troph.grp=="Top predators"])
  }
}

# for every combination of size and productivity, get number of species per Class,  
res.sz.Myx  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Myx) <- res.grp;colnames(res.sz.Myx) <- sz.grp
res.sz.Pet  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Pet) <- res.grp;colnames(res.sz.Pet) <- sz.grp
res.sz.Hol  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Hol) <- res.grp;colnames(res.sz.Hol) <- sz.grp
res.sz.Ela  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Ela) <- res.grp;colnames(res.sz.Ela) <- sz.grp
res.sz.Cla  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Cla) <- res.grp;colnames(res.sz.Cla) <- sz.grp
res.sz.Act  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Act) <- res.grp;colnames(res.sz.Act) <- sz.grp
res.sz.Coe  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Coe) <- res.grp;colnames(res.sz.Coe) <- sz.grp
res.sz.Dip  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Dip) <- res.grp;colnames(res.sz.Dip) <- sz.grp

for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.Myx[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==1])
    res.sz.Pet[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==2])
    res.sz.Hol[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==3])
    res.sz.Ela[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==4])
    res.sz.Cla[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==9])
    res.sz.Act[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==6])
    res.sz.Coe[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==10])
    res.sz.Dip[j,i] <- length(Bdat$SpecCode[size==i & res==j & Bdat$ClassNum==11])
  }
}

# create the biodiv plot 
windows(12,9)
par(oma=c(5,6,2,2),mar=c(0,0,0,0),mfrow=c(4,4)) # defines bottom and left outer margins, no inner margins, 4*4 panels
# print number of species in upper left corner
cw <- 2000 # number of species in cell width
for(i in 1:4) {
  for(j in 1:4) {
    plot(1,1,ylab="",xlab="",type="n",xaxt="n",yaxt="n")
    rect(xleft=1-(0.86/cw*res.sz.top[i,j])/2,ybottom=1.258,xright=1+(0.86/cw*res.sz.top[i,j])/2,ytop=1.43,col="red",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.mid[i,j])/2,ybottom=1.086,xright=1+(0.86/cw*res.sz.mid[i,j])/2,ytop=1.258,col="orange",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.low[i,j])/2,ybottom=0.914,xright=1+(0.86/cw*res.sz.low[i,j])/2,ytop=1.086,col="yellow",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.omn[i,j])/2,ybottom=0.742,xright=1+(0.86/cw*res.sz.omn[i,j])/2,ytop=0.914,col="chartreuse1",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.herb[i,j])/2,ybottom=0.57,xright=1+(0.86/cw*res.sz.herb[i,j])/2,ytop=0.742,col="forestgreen",border=NA)
    if(res.sz.low[i,j]>cw) {
      lines(x=c(0.57,0.57),y=c(0.914,1.086))
      text(x=1,y=1,paste("<             ",res.sz.low[i,j],"             >"))
    }
    legend("topright",legend=paste(res.sz.counts[i,j],"\n",
                  ifelse(is.na(res.sz.age[i,j])==F,format(res.sz.age[i,j],digits=0),"")),box.lty=0)
    
    class.dat <- data.frame(class=c("Myx","Pet","Hol","Ela","Cla","Act","Coe","Dip"),
                            n=c(res.sz.Myx[i,j],res.sz.Pet[i,j],res.sz.Hol[i,j],res.sz.Ela[i,j],
                                res.sz.Cla[i,j],res.sz.Act[i,j],res.sz.Coe[i,j],res.sz.Dip[i,j]),
                                stringsAsFactors = FALSE)
    class.dat <- class.dat[class.dat$n>0,]
    class.dat <- class.dat[order(class.dat$n,decreasing = T),]
    class.str <- paste(class.dat$class,collapse = " ")
    legend("bottomleft",class.str,box.lty=0)
                            
  }
}
# Add labels
mtext(text="Small",at=0.12,side=1,line=1,outer=TRUE)
mtext(text="Medium",at=0.37,side=1,line=1,outer=TRUE)
mtext(text="Large",at=0.62,side=1,line=1,outer=TRUE)
mtext(text="Very large",at=0.87,side=1,line=1,outer=TRUE)
mtext(text="Size",side=1,line=3,outer=TRUE,cex=1.3)
mtext(text="Very low",at=0.12,side=2,line=1,outer=TRUE)
mtext(text="Low",at=0.36,side=2,line=1,outer=TRUE)
mtext(text="Medium",at=0.62,side=2,line=1,outer=TRUE)
mtext(text="High",at=0.87,side=2,line=1,outer=TRUE)
mtext(text="Productivity",side=2,line=3,outer=TRUE,cex=1.3)
# Add sums
mtext(text=sz.count[1],at=0.22,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count[2],at=0.465,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count[3],at=0.72,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count[4],at=0.98,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count[4],at=0.22,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count[3],at=0.465,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count[2],at=0.715,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count[1],at=0.965,side=2,line=0,outer=TRUE,cex=0.7)

# Print list of theoretical combinations with number of species
lhspt <- array(,dim = c(4,4,5),dimnames=list(res.grp,sz.grp,tr.grp))

for(i in 1:4){
  for(j in 1:4){
    for(k in 1:5){
      lhspt[i,j,k]<-length(sp[size==sz.grp[i]&res==res.grp[j]&troph.grp==tr.grp[k]])
      cat(sz.grp[i],res.grp[j],tr.grp[k],length(sp[size==sz.grp[i]&res==res.grp[j]&troph.grp==tr.grp[k]]),"\n")
    }
  }
}

#---------------------------------------------------------------------------
# Bodyshape form factor by size, productivity and trophic level
#---------------------------------------------------------------------------
# calculate the form factor based on equation 18 in Froese 2006
ff <- vector()
for(i in 1:length(sp)){
  ff[i] <- 10^(log10(Bdat$a[i])+1.358*(Bdat$b[i]-3))    
}

# plot histogram of form factor 
windows(12,8)
h.ff <- hist(ff,breaks = 25,main="",xlab="Form factor")

# Prepare biodiv form factor plot
res.sz.ff <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.ff) <- res.grp
colnames(res.sz.ff) <- sz.grp

# get number of species per size group and resilience group
res.ff    <- vector(); for(i in 1:4) {res.ff[i] <- median(ff[res==res.grp[i]],na.rm=T) }
sz.ff     <- vector(); for(i in 1:4) {sz.ff[i] <- median(ff[size==sz.grp[i]],na.rm=T) }
sz.ff     <- vector(); for(i in 1:4) {sz.ff[i] <- median(ff[size==sz.grp[i]],na.rm=T) }
sz.ff.5   <- vector(); for(i in 1:4) {sz.ff.5[i] <- quantile(ff[size==sz.grp[i]],na.rm=T,0.05) }
sz.ff.95  <- vector(); for(i in 1:4) {sz.ff.95[i] <- quantile(ff[size==sz.grp[i]],na.rm=T,0.95) }

# assign counts of species to matrix, add totals to matrix and print matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.ff[j,i] <- median(ff[size==i & res==j],na.rm=T) 
  }
}

# for every combination of size and productivity, get median ff per trophic group,  
res.sz.herb.ff <- matrix(,nrow=4,ncol = 4);rownames(res.sz.herb.ff) <- res.grp;colnames(res.sz.herb.ff) <- sz.grp
res.sz.omn.ff  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.omn.ff)  <- res.grp;colnames(res.sz.omn.ff) <- sz.grp
res.sz.low.ff  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.low.ff) <- res.grp;colnames(res.sz.low.ff) <- sz.grp
res.sz.mid.ff  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.mid.ff) <- res.grp;colnames(res.sz.mid.ff) <- sz.grp
res.sz.top.ff  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.top.ff) <- res.grp;colnames(res.sz.top.ff) <- sz.grp
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.herb.ff[j,i] <- ifelse(length(ff[size==i & res==j & troph.grp=="Herbivores"])<4,NA,
                                  median(ff[size==i & res==j & troph.grp=="Herbivores"]))
    res.sz.omn.ff[j,i] <- ifelse(length(ff[size==i & res==j & troph.grp=="Omnivores"])<4,NA,
                                  median(ff[size==i & res==j & troph.grp=="Omnivores"]))
    res.sz.low.ff[j,i] <- ifelse(length(ff[size==i & res==j & troph.grp=="Low-level predators"])<4,NA,
                                  median(ff[size==i & res==j & troph.grp=="Low-level predators"]))
    res.sz.mid.ff[j,i] <- ifelse(length(ff[size==i & res==j & troph.grp=="Mid-level predators"])<4,NA,
                                  median(ff[size==i & res==j & troph.grp=="Mid-level predators"]))
    res.sz.top.ff[j,i] <- ifelse(length(ff[size==i & res==j & troph.grp=="Top predators"])<4,NA,
                                  median(ff[size==i & res==j & troph.grp=="Top predators"]))
  }
}


# create the biodiv plot 
windows(12,9)
par(oma=c(5,6,2,2),mar=c(0,0,0,0),mfrow=c(4,4)) # defines bottom and left outer margins, no inner margins, 4*4 panels
# print number of species in upper left corner
cw <- 2000 # number of species in cell width
yplus <- 0.1
for(i in 1:4) {
  for(j in 1:4) {
    plot(1,1,ylab="",xlab="",type="n",xaxt="n",yaxt="n")
    rect(xleft=1-(0.86/cw*res.sz.top[i,j])/2,ybottom=1.258,xright=1+(0.86/cw*res.sz.top[i,j])/2,ytop=1.43,col="red",border=NA)
    text(x=1,y=1.258+yplus,ifelse(is.na(res.sz.top.ff[i,j]),"",format(res.sz.top.ff[i,j],digits=2)))
    rect(xleft=1-(0.86/cw*res.sz.mid[i,j])/2,ybottom=1.086,xright=1+(0.86/cw*res.sz.mid[i,j])/2,ytop=1.258,col="orange",border=NA)
    text(x=1,y=1.086+yplus,ifelse(is.na(res.sz.mid.ff[i,j]),"",format(res.sz.mid.ff[i,j],digits=2)))
    rect(xleft=1-(0.86/cw*res.sz.low[i,j])/2,ybottom=0.914,xright=1+(0.86/cw*res.sz.low[i,j])/2,ytop=1.086,col="yellow",border=NA)
    text(x=1,y=0.914+yplus,ifelse(is.na(res.sz.low.ff[i,j]),"",format(res.sz.low.ff[i,j],digits=2)))
    rect(xleft=1-(0.86/cw*res.sz.omn[i,j])/2,ybottom=0.742,xright=1+(0.86/cw*res.sz.omn[i,j])/2,ytop=0.914,col="chartreuse1",border=NA)
    text(x=1,y=0.742+yplus,ifelse(is.na(res.sz.omn.ff[i,j]),"",format(res.sz.omn.ff[i,j],digits=2)))
    rect(xleft=1-(0.86/cw*res.sz.herb[i,j])/2,ybottom=0.57,xright=1+(0.86/cw*res.sz.herb[i,j])/2,ytop=0.742,col="forestgreen",border=NA)
    text(x=1,y=0.57+yplus,ifelse(is.na(res.sz.herb.ff[i,j]),"",format(res.sz.herb.ff[i,j],digits=2)))
    if(res.sz.low[i,j]>cw) {lines(x=c(0.57,0.57),y=c(0.914,1.086))}   
    legend("topright",legend=ifelse(is.na(res.sz.ff[i,j]),"",format(res.sz.ff[i,j],digits=2)),box.lty=0) 
  }
}
# Add labels
mtext(text="Small",at=0.12,side=1,line=1,outer=TRUE)
mtext(text="Medium",at=0.37,side=1,line=1,outer=TRUE)
mtext(text="Large",at=0.62,side=1,line=1,outer=TRUE)
mtext(text="Very large",at=0.87,side=1,line=1,outer=TRUE)
mtext(text="Size",side=1,line=3,outer=TRUE,cex=1.3)
mtext(text="Very low",at=0.12,side=2,line=1,outer=TRUE)
mtext(text="Low",at=0.36,side=2,line=1,outer=TRUE)
mtext(text="Medium",at=0.62,side=2,line=1,outer=TRUE)
mtext(text="High",at=0.87,side=2,line=1,outer=TRUE)
mtext(text="Productivity",side=2,line=3,outer=TRUE,cex=1.3)
# Add sums
mtext(text=paste(format(sz.ff[1],digits=2),",",format(sz.ff.5[1],digits=2),"-",format(sz.ff.95[1],digits=2)),at=0.12,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=paste(format(sz.ff[2],digits=2),",",format(sz.ff.5[2],digits=2),"-",format(sz.ff.95[2],digits=2)),at=0.365,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=paste(format(sz.ff[3],digits=2),",",format(sz.ff.5[3],digits=2),"-",format(sz.ff.95[3],digits=2)),at=0.62,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=paste(format(sz.ff[4],digits=2),",",format(sz.ff.5[4],digits=2),"-",format(sz.ff.95[4],digits=2)),at=0.88,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=format(res.ff[4],digits=2),at=0.22,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=format(res.ff[3],digits=2),at=0.465,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=format(res.ff[2],digits=2),at=0.715,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=format(res.ff[1],digits=2),at=0.965,side=2,line=0,outer=TRUE,cex=0.7)

# count strategies used by Class
cat("Number of strategies used by Class\n")
for(i in c(1,2,3,4,6,9,10,11)) {
  str.used <- 0
  for(j in sz.grp){
    for(k in res.grp){
      for(l in tr.grp){
        if(length(sp[Bdat$ClassNum==i & size==j & res==k & troph.grp==l])>0) {
          str.used <- str.used+1  } 
      }
    }
  }
  cat("\nClass:",unique(Bdat$Class[Bdat$ClassNum==i]),", strategies used =",str.used,"\n")
}


#-----------------------------------------------------------------------------
# Marine biodiversity plot
#-----------------------------------------------------------------------------
cat("Marine Biodiversity ----------------------------\n")
# Create resilience and size groups and matrix to store counts
res.sz.counts.M <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.counts.M) <- res.grp
colnames(res.sz.counts.M) <- sz.grp
res.sz.age.M    <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.age.M) <- res.grp
colnames(res.sz.age.M) <- sz.grp

# get number of species per size group and resilience group
res.count.M  <- vector(); for(i in 1:4) {res.count.M[i] <- length(res[Bdat$Saltwater==1&Bdat$Fresh==0 & res==res.grp[i]]) }
sz.count.M   <- vector(); for(i in 1:4) {sz.count.M[i] <- length(size[Bdat$Saltwater==1&Bdat$Fresh==0 & size==sz.grp[i]]) }

# assign counts of species to matrix, add totals to matrix and print matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.counts.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i&res==j]) 
  }
}
res.sz.counts.M <- cbind(res.sz.counts.M,res.count.M)
sz.count.M      <- append(sz.count.M,length(res[Bdat$Saltwater==1&Bdat$Fresh==0]))
res.sz.counts.M <- rbind(res.sz.counts.M,sz.count.M)

# assign counts of species to matrix, add totals to matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.counts.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j]) 
  }
}

# get median age of Orders of species in a cell, assign to res.sz.age matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.age.M[j,i] <- median(OAge[Bdat$Saltwater==1&Bdat$Fresh==0&size==i&res==j]) 
  }
}

# for every combination of size and productivity, get number of species per trophic group,  
res.sz.herb.M <- matrix(,nrow=4,ncol = 4);rownames(res.sz.herb.M) <- res.grp;colnames(res.sz.herb.M) <- sz.grp
res.sz.omn.M  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.omn.M)  <- res.grp;colnames(res.sz.omn.M) <- sz.grp
res.sz.low.M  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.low.M) <- res.grp;colnames(res.sz.low.M) <- sz.grp
res.sz.mid.M  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.mid.M) <- res.grp;colnames(res.sz.mid.M) <- sz.grp
res.sz.top.M  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.top.M) <- res.grp;colnames(res.sz.top.M) <- sz.grp
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.herb.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & troph.grp=="Herbivores"])
    res.sz.omn.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & troph.grp=="Omnivores"])
    res.sz.low.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & troph.grp=="Low-level predators"])
    res.sz.mid.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & troph.grp=="Mid-level predators"])
    res.sz.top.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & troph.grp=="Top predators"])
  }
}

cat("\n Herb M:",sum(res.sz.herb.M),"\n")
cat("Omn M:",sum(res.sz.omn.M),"\n")
cat("Low M:",sum(res.sz.low.M),"\n")
cat("Mid M:",sum(res.sz.mid.M),"\n")
cat("Top M:",sum(res.sz.herb.M),"\n\n")

# for every combination of size and productivity, get number of species per Class,  
res.sz.Myx.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Myx.M) <- res.grp;colnames(res.sz.Myx.M) <- sz.grp
res.sz.Pet.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Pet.M) <- res.grp;colnames(res.sz.Pet.M) <- sz.grp
res.sz.Hol.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Hol.M) <- res.grp;colnames(res.sz.Hol.M) <- sz.grp
res.sz.Ela.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Ela.M) <- res.grp;colnames(res.sz.Ela.M) <- sz.grp
res.sz.Cla.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Cla.M) <- res.grp;colnames(res.sz.Cla.M) <- sz.grp
res.sz.Act.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Act.M) <- res.grp;colnames(res.sz.Act.M) <- sz.grp
res.sz.Coe.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Coe.M) <- res.grp;colnames(res.sz.Coe.M) <- sz.grp
res.sz.Dip.M  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Dip.M) <- res.grp;colnames(res.sz.Dip.M) <- sz.grp

for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.Myx.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==1])
    res.sz.Pet.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==2])
    res.sz.Hol.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==3])
    res.sz.Ela.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==4])
    res.sz.Cla.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==9])
    res.sz.Act.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==6])
    res.sz.Coe.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==10])
    res.sz.Dip.M[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==1&Bdat$Fresh==0&size==i & res==j & Bdat$ClassNum==11])
  }
}

# create the marine biodiv plot 
windows(12,9)
par(oma=c(5,5,2,2),mar=c(0,0,0,0),mfrow=c(4,4)) # defines bottom and left outer margins, no inner margins, 4*4 panels
# print number of species in upper left corner
cw <- 1000 # number of species in cell width
for(i in 1:4) {
  for(j in 1:4) {
    plot(1,1,ylab="",xlab="",type="n",xaxt="n",yaxt="n")
    rect(xleft=1-(0.86/cw*res.sz.top.M[i,j])/2,ybottom=1.258,xright=1+(0.86/cw*res.sz.top.M[i,j])/2,ytop=1.43,col="red",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.mid.M[i,j])/2,ybottom=1.086,xright=1+(0.86/cw*res.sz.mid.M[i,j])/2,ytop=1.258,col="orange",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.low.M[i,j])/2,ybottom=0.914,xright=1+(0.86/cw*res.sz.low.M[i,j])/2,ytop=1.086,col="yellow",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.omn.M[i,j])/2,ybottom=0.742,xright=1+(0.86/cw*res.sz.omn.M[i,j])/2,ytop=0.914,col="chartreuse1",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.herb.M[i,j])/2,ybottom=0.57,xright=1+(0.86/cw*res.sz.herb.M[i,j])/2,ytop=0.742,col="forestgreen",border=NA)
    if(res.sz.low.M[i,j]>cw) {
      lines(x=c(0.565,0.565),y=c(0.914,1.086)) # fix disappearance of border, original 0.57
      text(x=1,y=1,paste("<             ",res.sz.low.M[i,j],"             >"))
    }
   # legend("topright",legend=res.sz.counts.M[i,j],box.lty=0)
    legend("topright",legend=paste(res.sz.counts.M[i,j],"\n",
                  ifelse(is.na(res.sz.age.M[i,j])==F,format(res.sz.age.M[i,j],digits=0),"")),box.lty=0)
 
    class.dat <- data.frame(class=c("Myx","Pet","Hol","Ela","Cla","Act","Coe","Dip"),
                            n=c(res.sz.Myx.M[i,j],res.sz.Pet.M[i,j],res.sz.Hol.M[i,j],res.sz.Ela.M[i,j],
                            res.sz.Cla.M[i,j],res.sz.Act.M[i,j],res.sz.Coe.M[i,j],res.sz.Dip.M[i,j]),
                            stringsAsFactors = FALSE)
    class.dat <- class.dat[class.dat$n>0,]
    class.dat <- class.dat[order(class.dat$n,decreasing = T),]
    class.str <- paste(class.dat$class,collapse = " ")
    legend("bottomleft",class.str,box.lty=0)
  }
}
# Add labels
mtext(text="Small",at=0.12,side=1,line=1,outer=TRUE)
mtext(text="Medium",at=0.37,side=1,line=1,outer=TRUE)
mtext(text="Large",at=0.62,side=1,line=1,outer=TRUE)
mtext(text="Very large",at=0.87,side=1,line=1,outer=TRUE)
mtext(text="Size",side=1,line=3,outer=TRUE,cex=1.3)
mtext(text="Very low",at=0.12,side=2,line=1,outer=TRUE)
mtext(text="Low",at=0.36,side=2,line=1,outer=TRUE)
mtext(text="Medium",at=0.62,side=2,line=1,outer=TRUE)
mtext(text="High",at=0.87,side=2,line=1,outer=TRUE)
mtext(text="Productivity",side=2,line=3,outer=TRUE,cex=1.3)
# Add sums
mtext(text=sz.count.M[1],at=0.22,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.M[2],at=0.465,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.M[3],at=0.72,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.M[4],at=0.98,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.M[4],at=0.22,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.M[3],at=0.465,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.M[2],at=0.715,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.M[1],at=0.965,side=2,line=0,outer=TRUE,cex=0.7)

cat("\nSum of marine fish:",sum(res.count.M),"\n")

#-----------------------------------------------------------------------------
# Freshwater biodiversity plot
#-----------------------------------------------------------------------------
cat("Freshwater Biodiversity ----------------------------\n")
# Create resilience and size groups and matrix to store counts
res.sz.counts.F <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.counts.F) <- res.grp
colnames(res.sz.counts.F) <- sz.grp
res.sz.age.F    <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.age.F) <- res.grp
colnames(res.sz.age.F) <- sz.grp

# get number of species per size group and resilience group
res.count.F  <- vector(); for(i in 1:4) {res.count.F[i] <- length(res[Bdat$Saltwater==0&Bdat$Fresh==1 & res==res.grp[i]]) }
sz.count.F   <- vector(); for(i in 1:4) {sz.count.F[i] <- length(size[Bdat$Saltwater==0&Bdat$Fresh==1 & size==sz.grp[i]]) }

# assign counts of species to matrix, add totals to matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.counts.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i&res==j]) 
  }
}

# get median age of Orders of species in a cell, assign to res.sz.age.F matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.age.F[j,i] <- median(OAge[Bdat$Saltwater==0&Bdat$Fresh==1&size==i&res==j]) 
  }
}

# for every combination of size and productivity, get number of species per trophic group,  
res.sz.herb.F <- matrix(,nrow=4,ncol = 4);rownames(res.sz.herb.F) <- res.grp;colnames(res.sz.herb.F) <- sz.grp
res.sz.omn.F   <- matrix(,nrow=4,ncol = 4);rownames(res.sz.omn.F)  <- res.grp;colnames(res.sz.omn.F) <- sz.grp
res.sz.low.F  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.low.F) <- res.grp;colnames(res.sz.low.F) <- sz.grp
res.sz.mid.F  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.mid.F) <- res.grp;colnames(res.sz.mid.F) <- sz.grp
res.sz.top.F  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.top.F) <- res.grp;colnames(res.sz.top.F) <- sz.grp

for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.herb.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & troph.grp=="Herbivores"])
    res.sz.omn.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & troph.grp=="Omnivores"])
    res.sz.low.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & troph.grp=="Low-level predators"])
    res.sz.mid.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & troph.grp=="Mid-level predators"])
    res.sz.top.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & troph.grp=="Top predators"])
  }
}

cat("\n Herb F:",sum(res.sz.herb.F),"\n")
cat("Omn F:",sum(res.sz.omn.F),"\n")
cat("Low F:",sum(res.sz.low.F),"\n")
cat("Mid F:",sum(res.sz.mid.F),"\n")
cat("Top F:",sum(res.sz.top.F),"\n\n")

# for every combination of size and productivity, get number of species per Class,  
res.sz.Myx.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Myx.F) <- res.grp;colnames(res.sz.Myx.F) <- sz.grp
res.sz.Pet.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Pet.F) <- res.grp;colnames(res.sz.Pet.F) <- sz.grp
res.sz.Hol.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Hol.F) <- res.grp;colnames(res.sz.Hol.F) <- sz.grp
res.sz.Ela.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Ela.F) <- res.grp;colnames(res.sz.Ela.F) <- sz.grp
res.sz.Cla.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Cla.F) <- res.grp;colnames(res.sz.Cla.F) <- sz.grp
res.sz.Act.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Act.F) <- res.grp;colnames(res.sz.Act.F) <- sz.grp
res.sz.Coe.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Coe.F) <- res.grp;colnames(res.sz.Coe.F) <- sz.grp
res.sz.Dip.F  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Dip.F) <- res.grp;colnames(res.sz.Dip.F) <- sz.grp

for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.Myx.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==1])
    res.sz.Pet.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==2])
    res.sz.Hol.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==3])
    res.sz.Ela.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==4])
    res.sz.Cla.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==9])
    res.sz.Act.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==6])
    res.sz.Coe.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==10])
    res.sz.Dip.F[j,i] <- length(Bdat$SpecCode[Bdat$Saltwater==0&Bdat$Fresh==1&size==i & res==j & Bdat$ClassNum==11])
  }
}

# create the biodiv plot 
windows(12,9)
par(oma=c(5,5,2,2),mar=c(0,0,0,0),mfrow=c(4,4)) # defines bottom and left outer margins, no inner margins, 4*4 panels
# print number of species in upper left corner
cw <- 1000 # number of species in cell width
for(i in 1:4) {
  for(j in 1:4) {
    plot(1,1,ylab="",xlab="",type="n",xaxt="n",yaxt="n")
    rect(xleft=1-(0.86/cw*res.sz.top.F[i,j])/2,ybottom=1.258,xright=1+(0.86/cw*res.sz.top.F[i,j])/2,ytop=1.43,col="red",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.mid.F[i,j])/2,ybottom=1.086,xright=1+(0.86/cw*res.sz.mid.F[i,j])/2,ytop=1.258,col="orange",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.low.F[i,j])/2,ybottom=0.914,xright=1+(0.86/cw*res.sz.low.F[i,j])/2,ytop=1.086,col="yellow",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.omn.F[i,j])/2,ybottom=0.742,xright=1+(0.86/cw*res.sz.omn.F[i,j])/2,ytop=0.914,col="chartreuse1",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.herb.F[i,j])/2,ybottom=0.57,xright=1+(0.86/cw*res.sz.herb.F[i,j])/2,ytop=0.742,col="forestgreen",border=NA)
    if(res.sz.low.F[i,j]>cw) {
      lines(x=c(0.565,0.565),y=c(0.914,1.086)) # fix border, orig x=c(0.57,0.57)
      text(x=1,y=1,paste("<             ",res.sz.low.F[i,j],"             >"))
    }
    #legend("topright",legend=res.sz.counts.F[i,j],box.lty=0)
    legend("topright",legend=paste(res.sz.counts.F[i,j],"\n",
                    ifelse(is.na(res.sz.age.F[i,j])==F,format(res.sz.age.F[i,j],digits=0),"")),box.lty=0)
    class.dat <- data.frame(class=c("Myx","Pet","Hol","Ela","Cla","Act","Coe","Dip"),
                            n=c(res.sz.Myx.F[i,j],res.sz.Pet.F[i,j],res.sz.Hol.F[i,j],res.sz.Ela.F[i,j],
                                res.sz.Cla.F[i,j],res.sz.Act.F[i,j],res.sz.Coe.F[i,j],res.sz.Dip.F[i,j]),
                            stringsAsFactors = FALSE)
    class.dat <- class.dat[class.dat$n>0,]
    class.dat <- class.dat[order(class.dat$n,decreasing = T),]
    class.str <- paste(class.dat$class,collapse = " ")
    legend("bottomleft",class.str,box.lty=0)
  }
}
# Add labels
mtext(text="Small",at=0.12,side=1,line=1,outer=TRUE)
mtext(text="Medium",at=0.37,side=1,line=1,outer=TRUE)
mtext(text="Large",at=0.62,side=1,line=1,outer=TRUE)
mtext(text="Very large",at=0.87,side=1,line=1,outer=TRUE)
mtext(text="Size",side=1,line=3,outer=TRUE,cex=1.3)
# Add sums
mtext(text=sz.count.F[1],at=0.22,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.F[2],at=0.465,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.F[3],at=0.72,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.F[4],at=0.98,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.F[4],at=0.22,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.F[3],at=0.465,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.F[2],at=0.715,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.F[1],at=0.965,side=2,line=0,outer=TRUE,cex=0.7)

cat("\nSum of freshwater fish:",sum(res.count.F),"\n")


#-----------------------------------------------------------------------------
# Biodiv Plot for Arctic fishes in 2000
#-----------------------------------------------------------------------------

# read file with Arctic SynCodes for 2000
SC2000       <- read.csv("SynCode2000.csv")
SynCode2000  <- SC2000[,2]

# Create resilience and size groups and matrix to store counts
res.sz.counts.A20 <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.counts.A20) <- res.grp
colnames(res.sz.counts.A20) <- sz.grp
res.sz.age.A20    <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.age.A20) <- res.grp
colnames(res.sz.age.A20) <- sz.grp

# get number of species per size group and resilience group
res.count.A20  <- vector(); for(i in 1:4) {res.count.A20[i] <- length(res[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 & res==res.grp[i]]) }
sz.count.A20   <- vector(); for(i in 1:4) {sz.count.A20[i] <- length(size[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 & size==sz.grp[i]]) }

# assign counts of species to matrix, add totals to matrix and print matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.counts.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i&res==j]) 
  }
}
res.sz.counts.A20 <- cbind(res.sz.counts.A20,res.count.A20)
sz.count.A20      <- append(sz.count.A20,length(res[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0]))
res.sz.counts.A20 <- rbind(res.sz.counts.A20,sz.count.A20)

# assign counts of species to matrix, add totals to matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.counts.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j]) 
  }
}

# get median age of Orders of species in a cell, assign to res.sz.age matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.age.A20[j,i] <- median(OAge[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i&res==j]) 
  }
}

# for every combination of size and productivity, get number of species per trophic group,  
res.sz.herb.A20 <- matrix(,nrow=4,ncol = 4);rownames(res.sz.herb.A20) <- res.grp;colnames(res.sz.herb.A20) <- sz.grp
res.sz.omn.A20   <- matrix(,nrow=4,ncol = 4);rownames(res.sz.omn.A20)  <- res.grp;colnames(res.sz.omn.A20) <- sz.grp
res.sz.low.A20  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.low.A20) <- res.grp;colnames(res.sz.low.A20) <- sz.grp
res.sz.mid.A20  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.mid.A20) <- res.grp;colnames(res.sz.mid.A20) <- sz.grp
res.sz.top.A20  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.top.A20) <- res.grp;colnames(res.sz.top.A20) <- sz.grp
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.herb.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Herbivores"])
    res.sz.omn.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Omnivores"])
    res.sz.low.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Low-level predators"])
    res.sz.mid.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Mid-level predators"])
    res.sz.top.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Top predators"])
  }
}

# for every combination of size and productivity, get number of species per Class,  
res.sz.Myx.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Myx.A20) <- res.grp;colnames(res.sz.Myx.A20) <- sz.grp
res.sz.Pet.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Pet.A20) <- res.grp;colnames(res.sz.Pet.A20) <- sz.grp
res.sz.Hol.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Hol.A20) <- res.grp;colnames(res.sz.Hol.A20) <- sz.grp
res.sz.Ela.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Ela.A20) <- res.grp;colnames(res.sz.Ela.A20) <- sz.grp
res.sz.Cla.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Cla.A20) <- res.grp;colnames(res.sz.Cla.A20) <- sz.grp
res.sz.Act.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Act.A20) <- res.grp;colnames(res.sz.Act.A20) <- sz.grp
res.sz.Coe.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Coe.A20) <- res.grp;colnames(res.sz.Coe.A20) <- sz.grp
res.sz.Dip.A20  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Dip.A20) <- res.grp;colnames(res.sz.Dip.A20) <- sz.grp

for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.Myx.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==1])
    res.sz.Pet.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==2])
    res.sz.Hol.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==3])
    res.sz.Ela.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==4])
    res.sz.Cla.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==9])
    res.sz.Act.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==6])
    res.sz.Coe.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==10])
    res.sz.Dip.A20[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2000 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==11])
  }
}

# create the Arctic biodiv plot 
windows(12,9)
par(oma=c(5,5,2,2),mar=c(0,0,0,0),mfrow=c(4,4)) # defines bottom and left outer margins, no inner margins, 4*4 panels
# print number of species in upper left corner
cw <- 100 # number of species in cell width
for(i in 1:4) {
  for(j in 1:4) {
    plot(1,1,ylab="",xlab="",type="n",xaxt="n",yaxt="n")
    rect(xleft=1-(0.86/cw*res.sz.top.A20[i,j])/2,ybottom=1.258,xright=1+(0.86/cw*res.sz.top.A20[i,j])/2,ytop=1.43,col="red",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.mid.A20[i,j])/2,ybottom=1.086,xright=1+(0.86/cw*res.sz.mid.A20[i,j])/2,ytop=1.258,col="orange",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.low.A20[i,j])/2,ybottom=0.914,xright=1+(0.86/cw*res.sz.low.A20[i,j])/2,ytop=1.086,col="yellow",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.omn.A20[i,j])/2,ybottom=0.742,xright=1+(0.86/cw*res.sz.omn.A20[i,j])/2,ytop=0.914,col="chartreuse1",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.herb.A20[i,j])/2,ybottom=0.57,xright=1+(0.86/cw*res.sz.herb.A20[i,j])/2,ytop=0.742,col="forestgreen",border=NA)
    if(res.sz.low.A20[i,j]>cw) {
      lines(x=c(0.565,0.565),y=c(0.914,1.086)) # fix disappearance of border, original 0.57
      text(x=1,y=1,paste("<             ",res.sz.low.A20[i,j],"             >"))
    }
    # legend("topright",legend=res.sz.counts.A20[i,j],box.lty=0)
    legend("topright",legend=paste(res.sz.counts.A20[i,j],"\n",
                                   ifelse(is.na(res.sz.age.A20[i,j])==F,format(res.sz.age.A20[i,j],digits=0),"")),box.lty=0)
    
    class.dat <- data.frame(class=c("Myx","Pet","Hol","Ela","Cla","Act","Coe","Dip"),
                            n=c(res.sz.Myx.A20[i,j],res.sz.Pet.A20[i,j],res.sz.Hol.A20[i,j],res.sz.Ela.A20[i,j],
                                res.sz.Cla.A20[i,j],res.sz.Act.A20[i,j],res.sz.Coe.A20[i,j],res.sz.Dip.A20[i,j]),
                            stringsAsFactors = FALSE)
    class.dat <- class.dat[class.dat$n>0,]
    class.dat <- class.dat[order(class.dat$n,decreasing = T),]
    class.str <- paste(class.dat$class,collapse = " ")
    legend("bottomleft",class.str,box.lty=0)
    
    # plot elongate demersal species symbol at mid-level predators group
    if(i==2 & j==2){
      asp    <- 12/9 # aspect ratio of window 
      tr     <- 1.086 # hight of troph: herb 0.57, omn 0.742, low 0.914, mid 1.086, top 1.258
      xoff   <- (1.43-0.57)/40  # x offset to position drawing in plot
      yoff   <- (1.43-0.57)/40  # y offset to position drawing in plot
      # lines(x=c(1,4,8,12,14,13.5,14,12,8,4,1)*xoff/asp+0.85,y=c(5,7,7,5.5,7,5,3,4.5,3,3,5)*yoff+tr) # fusiform
      lines(x=c(1,4,12,16,18,18,18,16,12,4,1)*xoff/asp+0.85,y=c(5,6.5,6.5,5.5,6.5,5,3.5,4.5,3.5,3.5,5)*yoff+tr) # elongated
      points(x=4*xoff/asp+0.85,y=5*yoff+tr,pch=16)
      lines(x=c(1,18)*xoff/asp+0.85,y=c(2,2)*yoff+tr,lwd=2)
    }
  }
}
# Add labels
mtext(text="Small",at=0.12,side=1,line=1,outer=TRUE)
mtext(text="Medium",at=0.37,side=1,line=1,outer=TRUE)
mtext(text="Large",at=0.62,side=1,line=1,outer=TRUE)
mtext(text="Very large",at=0.87,side=1,line=1,outer=TRUE)
mtext(text="Size",side=1,line=3,outer=TRUE,cex=1.3)
mtext(text="Very low",at=0.12,side=2,line=1,outer=TRUE)
mtext(text="Low",at=0.36,side=2,line=1,outer=TRUE)
mtext(text="Medium",at=0.62,side=2,line=1,outer=TRUE)
mtext(text="High",at=0.87,side=2,line=1,outer=TRUE)
mtext(text="Productivity",side=2,line=3,outer=TRUE,cex=1.3)
# Add sums
mtext(text=sz.count.A20[1],at=0.22,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.A20[2],at=0.465,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.A20[3],at=0.72,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.A20[4],at=0.98,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A20[4],at=0.22,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A20[3],at=0.465,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A20[2],at=0.715,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A20[1],at=0.965,side=2,line=0,outer=TRUE,cex=0.7)

#-----------------------------------------------------------------------------
# Arctic biodiversity plot for 2100
#-----------------------------------------------------------------------------

# read file with Arctic SynCodes for 2100
SC2100       <- read.csv("SynCode2100.csv")
SynCode2100  <- SC2100[,2]

# Create resilience and size groups and matrix to store counts
res.sz.counts.A21 <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.counts.A21) <- res.grp
colnames(res.sz.counts.A21) <- sz.grp
res.sz.age.A21    <- matrix(,nrow=4,ncol = 4)
rownames(res.sz.age.A21) <- res.grp
colnames(res.sz.age.A21) <- sz.grp

# get number of species per size group and resilience group
res.count.A21  <- vector(); for(i in 1:4) {res.count.A21[i] <- length(res[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0  & res==res.grp[i]]) }
sz.count.A21   <- vector(); for(i in 1:4) {sz.count.A21[i] <- length(size[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0  & size==sz.grp[i]]) }

# assign counts of species to matrix, add totals to matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.counts.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i&res==j]) 
  }
}

# get median age of Orders of species in a cell, assign to res.sz.age.A21 matrix
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.age.A21[j,i] <- median(OAge[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i&res==j]) 
  }
}

# for every combination of size and productivity, get number of species per trophic group,  
res.sz.herb.A21 <- matrix(,nrow=4,ncol = 4);rownames(res.sz.herb.A21) <- res.grp;colnames(res.sz.herb.A21) <- sz.grp
res.sz.omn.A21   <- matrix(,nrow=4,ncol = 4);rownames(res.sz.omn.A21)  <- res.grp;colnames(res.sz.omn.A21) <- sz.grp
res.sz.low.A21  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.low.A21) <- res.grp;colnames(res.sz.low.A21) <- sz.grp
res.sz.mid.A21  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.mid.A21) <- res.grp;colnames(res.sz.mid.A21) <- sz.grp
res.sz.top.A21  <- matrix(,nrow=4,ncol = 4);rownames(res.sz.top.A21) <- res.grp;colnames(res.sz.top.A21) <- sz.grp
for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.herb.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Herbivores"])
    res.sz.omn.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Omnivores"])
    res.sz.low.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Low-level predators"])
    res.sz.mid.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Mid-level predators"])
    res.sz.top.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & troph.grp=="Top predators"])
  }
}

# for every combination of size and productivity, get number of species per Class,  
res.sz.Myx.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Myx.A21) <- res.grp;colnames(res.sz.Myx.A21) <- sz.grp
res.sz.Pet.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Pet.A21) <- res.grp;colnames(res.sz.Pet.A21) <- sz.grp
res.sz.Hol.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Hol.A21) <- res.grp;colnames(res.sz.Hol.A21) <- sz.grp
res.sz.Ela.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Ela.A21) <- res.grp;colnames(res.sz.Ela.A21) <- sz.grp
res.sz.Cla.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Cla.A21) <- res.grp;colnames(res.sz.Cla.A21) <- sz.grp
res.sz.Act.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Act.A21) <- res.grp;colnames(res.sz.Act.A21) <- sz.grp
res.sz.Coe.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Coe.A21) <- res.grp;colnames(res.sz.Coe.A21) <- sz.grp
res.sz.Dip.A21  <- matrix(,nrow=4,ncol=4);rownames(res.sz.Dip.A21) <- res.grp;colnames(res.sz.Dip.A21) <- sz.grp

for(i in sz.grp) {
  for(j in res.grp) {
    res.sz.Myx.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==1])
    res.sz.Pet.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==2])
    res.sz.Hol.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==3])
    res.sz.Ela.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==4])
    res.sz.Cla.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==9])
    res.sz.Act.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==6])
    res.sz.Coe.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==10])
    res.sz.Dip.A21[j,i] <- length(Bdat$SpecCode[Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0 &size==i & res==j & Bdat$ClassNum==11])
  }
}

# create the biodiv plot 
windows(12,9)
par(oma=c(5,5,2,2),mar=c(0,0,0,0),mfrow=c(4,4)) # defines bottom and left outer margins, no inner margins, 4*4 panels
# print number of species in upper left corner
cw <- 100 # number of species in cell width
for(i in 1:4) {
  for(j in 1:4) {
    plot(1,1,ylab="",xlab="",type="n",xaxt="n",yaxt="n")
    rect(xleft=1-(0.86/cw*res.sz.top.A21[i,j])/2,ybottom=1.258,xright=1+(0.86/cw*res.sz.top.A21[i,j])/2,ytop=1.43,col="red",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.mid.A21[i,j])/2,ybottom=1.086,xright=1+(0.86/cw*res.sz.mid.A21[i,j])/2,ytop=1.258,col="orange",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.low.A21[i,j])/2,ybottom=0.914,xright=1+(0.86/cw*res.sz.low.A21[i,j])/2,ytop=1.086,col="yellow",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.omn.A21[i,j])/2,ybottom=0.742,xright=1+(0.86/cw*res.sz.omn.A21[i,j])/2,ytop=0.914,col="chartreuse1",border=NA)
    rect(xleft=1-(0.86/cw*res.sz.herb.A21[i,j])/2,ybottom=0.57,xright=1+(0.86/cw*res.sz.herb.A21[i,j])/2,ytop=0.742,col="forestgreen",border=NA)
    if(res.sz.low.A21[i,j]>cw) {
      lines(x=c(0.565,0.565),y=c(0.914,1.086)) # fix border, orig x=c(0.57,0.57)
      text(x=1,y=1,paste("<             ",res.sz.low.A21[i,j],"             >"))
    }
    #legend("topright",legend=res.sz.counts.A21[i,j],box.lty=0)
    legend("topright",legend=paste(res.sz.counts.A21[i,j],"\n",
                                   ifelse(is.na(res.sz.age.A21[i,j])==F,format(res.sz.age.A21[i,j],digits=0),"")),box.lty=0)
    class.dat <- data.frame(class=c("Myx","Pet","Hol","Ela","Cla","Act","Coe","Dip"),
                            n=c(res.sz.Myx.A21[i,j],res.sz.Pet.A21[i,j],res.sz.Hol.A21[i,j],res.sz.Ela.A21[i,j],
                                res.sz.Cla.A21[i,j],res.sz.Act.A21[i,j],res.sz.Coe.A21[i,j],res.sz.Dip.A21[i,j]),
                            stringsAsFactors = FALSE)
    class.dat <- class.dat[class.dat$n>0,]
    class.dat <- class.dat[order(class.dat$n,decreasing = T),]
    class.str <- paste(class.dat$class,collapse = " ")
    legend("bottomleft",class.str,box.lty=0)
    
    # plot elongate demersal species symbol at mid-level predators group
    if(i==2 & j==2){
      asp    <- 12/9 # aspect ratio of window 
      tr     <- 1.086 # hight of troph: herb 0.57, omn 0.742, low 0.914, mid 1.086, top 1.258
      xoff   <- (1.43-0.57)/40  # x offset to position drawing in plot
      yoff   <- (1.43-0.57)/40  # y offset to position drawing in plot
      # lines(x=c(1,4,8,12,14,13.5,14,12,8,4,1)*xoff/asp+0.85,y=c(5,7,7,5.5,7,5,3,4.5,3,3,5)*yoff+tr) # fusiform
      lines(x=c(1,4,12,16,18,18,18,16,12,4,1)*xoff/asp+0.85,y=c(5,6.5,6.5,5.5,6.5,5,3.5,4.5,3.5,3.5,5)*yoff+tr) # elongated
      points(x=4*xoff/asp+0.85,y=5*yoff+tr,pch=16) # eye
      lines(x=c(1,18)*xoff/asp+0.85,y=c(2,2)*yoff+tr,lwd=2) # line for demersal
    }
    
    # plot demersal shark symbol at top predator group
    if(i==3 & j==3){ # large size, low productivity
      asp    <- 12/9 # aspect ratio of window 
      tr     <- 1.258 # hight of troph: herb 0.57, omn 0.742, low 0.914, mid 1.086, top 1.258
      xoff   <- (1.43-0.57)/40  # x offset to position drawing in plot
      yoff   <- (1.43-0.57)/40  # y offset to position drawing in plot
      lines(x=c(1,6,7,9,9,15,20,17,17,15,12,4,1)*xoff/asp+0.85,y=c(3.5,6,6,7,6,5,6.5,4.5,3.5,4,3.5,3.5,3.5)*yoff+tr) # shark
      points(x=3.5*xoff/asp+0.85,y=4*yoff+tr,pch=16,cex=0.7) # eye
      lines(x=c(1,18)*xoff/asp+0.85,y=c(2,2)*yoff+tr,lwd=2) # line for demersal
    }
    
  }
}
# Add labels
mtext(text="Small",at=0.12,side=1,line=1,outer=TRUE)
mtext(text="Medium",at=0.37,side=1,line=1,outer=TRUE)
mtext(text="Large",at=0.62,side=1,line=1,outer=TRUE)
mtext(text="Very large",at=0.87,side=1,line=1,outer=TRUE)
mtext(text="Size",side=1,line=3,outer=TRUE,cex=1.3)
# Add sums
mtext(text=sz.count.A21[1],at=0.22,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.A21[2],at=0.465,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.A21[3],at=0.72,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=sz.count.A21[4],at=0.98,side=1,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A21[4],at=0.22,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A21[3],at=0.465,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A21[2],at=0.715,side=2,line=0,outer=TRUE,cex=0.7)
mtext(text=res.count.A21[1],at=0.965,side=2,line=0,outer=TRUE,cex=0.7)


sp[troph.grp=="Mid-level predators" & size=="Medium" & res=="Medium" & Bdat$SynCode %in% SynCode2100 & Bdat$Fresh==0 & Bdat$Brack==0]

sp[size=="Medium" & res=="Very low"]

median(OAge[Bdat$Fresh==1])

